stalker.core.models.Department — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.models.Department

class `stalker.core.models.` `Department`(members=[], lead=None, **kwargs)

  Bases: `stalker.core.models.Entity`

  The departments that forms the studio itself.

  The informations that a Department object holds is like:

  > - The members of the department
  > - The lead of the department
  > - and all the other things those are inherited from the AuditEntity class

  Two Department object considered the same if they have the same name, the the members list nor the lead info is important, a “Modeling” department should of course be the same with another department which has the name “Modeling” again.

  so creating a department object needs the following parameters:

  Parameters: | members – it can be an empty list, so one department can be created without any member in it. But this parameter should be a list of User objects. lead – this is a User object, that holds the lead information, a lead could be in this department but it is not forced to be also a member of the department. So another departments member can be a lead for another department. Lead attribute can not be empty or None.

  `__init__`(members=[], lead=None, **kwargs)

  Methods

  `__init__`(**kwargs[, members, lead]) |

  Attributes

  `code` | The code name of this object.
  `created_by` | The `User` who has created this object.
  `date_created` | A `datetime.datetime` instance showing the creation date and time of this object.
  `date_updated` | A `datetime.datetime` instance showing the update date and time of this object.
  `description` | Description of this object.
  `lead` | lead is the lead of this department, it is a User object
  `members` | members are a list of users representing the members of this
  `name` | Name of this object
  `nice_name` | Nice name of this object.
  `notes` | All the notes about this entity.
  `tags` | A list of tags attached to this object.
  `type` | The type of the object.
  `updated_by` | The `User` who has updated this object.

  `members`

    members are a list of users representing the members of this department

  `lead`

    lead is the lead of this department, it is a User object

  `code`

    The code name of this object.

    It accepts string or unicode values and any other kind of objects will be converted to string. In any update to the name attribute the code also will be updated. If the code is not initialized or given as None, it will be set to the uppercase version of the nice_name attribute. Setting the code attribute to None will reset it to the default value. The default value is the upper case form of the nice_name.

  `created_by`

    The `User` who has created this object.

  `date_created`

    A `datetime.datetime` instance showing the creation date and time of this object.

  `date_updated`

    A `datetime.datetime` instance showing the update date and time of this object.

  `description`

    Description of this object.

  `name`

    Name of this object

  `nice_name`

    Nice name of this object.

    It has the same value with the name (contextually) but with a different format like, all the white spaces replaced by underscores (“_”), all the CamelCase form will be expanded by underscore (_) characters and it is always lower case.

    There is also the `code` attribute which is simply the upper case form of `nice_name` if it is not defined differently (i.e set to another value).

  `notes`

    All the notes about this entity.

    It is a list of `Note` objects or an empty list, None will be converted to an empty list.

  `tags`

    A list of tags attached to this object.

    It is a list of `Tag` instances which shows the tags of this object

  `type`

    The type of the object.

    It is an instance of `Type` with a proper `target_entity_type`.

  `updated_by`

    The `User` who has updated this object.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »